@@ -1,3 +1,5 @@
+import datetime
+
 import numpy as np
 import pytest
 from dnn_cool_synthetic_dataset.base import create_dataset
@@ -5,7 +7,7 @@ from mmap_ninja.ragged import RaggedMmap
 from mmap_ninja.string import StringsMmap
 from transformers import BertTokenizerFast
 
-from mmap_ninja_dataframe.base import generate_batches
+from mmap_ninja_dataframe.base import generate_batches, _create_mmap_for_key
 from mmap_ninja_dataframe.dense import DataFrameMmap
 
 
@@ -159,3 +161,12 @@ def test_performance(tmp_path):
     path.write_text('Something')
     df = DataFrameMmap(tmp_path / 'alternative')
     assert len(df) == len(dataframe_mmap)
+
+
+def test_create_datetime(tmp_path):
+    dates_str = [
+        '2005-12-01',
+        '2012-03-03'
+    ]
+    generator = list(map(np.datetime64, dates_str))
+    _create_mmap_for_key(tmp_path / 'out', key='datetime_out', values=generator, verbose=True)
